package org.firstinspires.ftc.teamcode;

import com.acmerobotics.dashboard.FtcDashboard;
import com.acmerobotics.dashboard.config.Config;
import com.acmerobotics.dashboard.telemetry.MultipleTelemetry;
import com.qualcomm.robotcore.eventloop.opmode.Autonomous;
import com.qualcomm.robotcore.eventloop.opmode.OpMode;

import org.firstinspires.ftc.robotcore.external.Telemetry;
import org.firstinspires.ftc.teamcode.pedroPathing.follower.Follower;
import org.firstinspires.ftc.teamcode.pedroPathing.pathGeneration.BezierCurve;
import org.firstinspires.ftc.teamcode.pedroPathing.pathGeneration.BezierLine;
import org.firstinspires.ftc.teamcode.pedroPathing.pathGeneration.PathChain;
import org.firstinspires.ftc.teamcode.pedroPathing.pathGeneration.Point;

/**
 * This is the Circle autonomous OpMode. It runs the robot in a PathChain that's actually not quite
 * a circle, but some Bezier curves that have control points set essentially in a square. However,
 * it turns enough to tune your centripetal force correction and some of your heading. Some lag in
 * heading is to be expected.
 *
 * @author Anyi Lin - 10158 Scott's Bots
 * @author Aaron Yang - 10158 Scott's Bots
 * @author Harrison Womack - 10158 Scott's Bots
 * @version 1.0, 3/12/2024
 */
@Config
@Autonomous (name = "Test", group = "Autonomous Pathing Tuning")
public class AutoTest extends OpMode {
    private Telemetry telemetryA;


    private Follower follower;

    private PathChain test;

    @Override
    public void init() {
        follower = new Follower(hardwareMap);

        test = follower.pathBuilder()
                .addPath(
        new BezierLine(
                new Point(8.000, 60.000, Point.CARTESIAN),
                new Point(18.000, 60.000, Point.CARTESIAN)
        )
      )

                .addPath(
                        // Line 2
                        new BezierCurve(
                                new Point(18.000, 60.000, Point.CARTESIAN),
                                new Point(18.000, 23.000, Point.CARTESIAN),
                                new Point(48.000, 23.000, Point.CARTESIAN)
                        )
                )

                .addPath(
                        // Line 3
                        new BezierLine(
                                new Point(48.000, 23.000, Point.CARTESIAN),
                                new Point(60.000, 36.000, Point.CARTESIAN)
                        )
                )

                .addPath(
                        // Line 4
                        new BezierLine(
                                new Point(60.000, 36.000, Point.CARTESIAN),
                                new Point(60.000, 49.000, Point.CARTESIAN)
                        )
                ).build();


        follower.followPath(test);

        telemetryA = new MultipleTelemetry(this.telemetry, FtcDashboard.getInstance().getTelemetry());
        telemetryA.update();
    }


    @Override
    public void loop() {
        follower.update();
        if (follower.atParametricEnd()) {
            follower.followPath(test);
        }

        follower.telemetryDebug(telemetryA);
    }
}
