package org.firstinspires.ftc.teamcode;

import com.qualcomm.hardware.rev.RevHubOrientationOnRobot;
import com.qualcomm.robotcore.hardware.DcMotorSimple.Direction;

import org.firstinspires.ftc.teamcode.pedroPathing.localization.Encoder;

public class PedroConstants {

    /*
        Robot parameters
    */

    // Robot motor configurations
    public static final String FRONT_LEFT_MOTOR = "front-left";
    public static final String BACK_LEFT_MOTOR  = "back-left";
    public static final String FRONT_RIGHT_MOTOR  = "front-right";
    public static final String BACK_RIGHT_MOTOR  = "back-right";

    // Robot motor direction
    public static final Direction FRONT_LEFT_MOTOR_DIRECTION = Direction.REVERSE;
    public static final Direction BACK_LEFT_MOTOR_DIRECTION = Direction.REVERSE;
    public static final Direction FRONT_RIGHT_MOTOR_DIRECTION = Direction.FORWARD;
    public static final Direction BACK_RIGHT_MOTOR_DIRECTION = Direction.FORWARD;

    // Robot IMU configuration
    public static final String IMU = "imu";

    // Robot IMU placement
    public static final RevHubOrientationOnRobot.LogoFacingDirection IMU_LOGO_FACING_DIRECTION
            = RevHubOrientationOnRobot.LogoFacingDirection.LEFT;
    public static final RevHubOrientationOnRobot.UsbFacingDirection IMU_USB_FACING_DIRECTION
            = RevHubOrientationOnRobot.UsbFacingDirection.UP;

    // Robot encoders
    public static final String LEFT_ENCODER = "encoder-left";
    public static final String RIGHT_ENCODER = "encoder-right";
    public static final String BACK_ENCODER = "encoder-back";

    // Robot encoder direction
    public static final double LEFT_ENCODER_DIRECTION = Encoder.FORWARD;
    public static final double RIGHT_ENCODER_DIRECTION = Encoder.FORWARD;
    public static final double BACK_ENCODER_DIRECTION = Encoder.REVERSE;

    // Arm config
    public static final String SLIDE_MOTOR = "SlideMotor";
    public static final String Claw_Servo = "ClawServo";
    public static final String Wrist_Servo = "WristServo";
    public static final String Arm_Servo = "ArmServo";

    /*
        Pedro's parameters
    */

    // The weight of the robot in Kilograms
    public static final double ROBOT_WEIGHT_IN_KG = 10.5;

    // Maximum velocity of the robot going forward
    public static final double ROBOT_SPEED_FORWARD = 72.0693;

    // Maximum velocity of the robot going right
    public static final double ROBOT_SPEED_LATERAL = 24.1401;

    // Rate of deceleration when power is cut-off when the robot is moving forward
    public static final double FORWARD_ZERO_POWER_ACCEL = -74.3779;

    // Rate of deceleration when power is cut-off when the robot is moving to the right
    public static final double LATERAL_ZERO_POWER_ACCEL = -111.8409;

    // Determines how fast your robot will decelerate as a factor of how fast your robot will coast to a stop
    public static final double ZERO_POWER_ACCEL_MULT = 4;

    /* Centripetal force correction - increase if robot is correcting into the path
                                    - decrease if robot is correcting away from the path */
    public static final double CENTRIPETAL_SCALING = 0.0005;
}
